@@ -20,7 +20,12 @@ def get_version() -> tuple:
 
 def increment_version(version: tuple, section: str) -> tuple:
     try:
-        return update_tuple(version, SECTIONS.index(section), lambda x: x+1)
+        new_version = update_tuple(version, SECTIONS.index(section), lambda x: x+1)
+        for s in SECTIONS[SECTIONS.index(section)+1:]:
+            new_version = update_tuple(new_version, SECTIONS.index(s), lambda _: 0)
+
+        return new_version
+
     except Exception:
         if section == 'label':
             raise NotImplementedError
@@ -58,7 +63,7 @@ def write_git_version(version) -> None:
 
 def commit_git_changes() -> None:
     init_path = get_init_path()
-    subprocess.call(["git", "add", init_path])
+    subprocess.call(["git", "add", init_path, "setup.py"])
     subprocess.call(["git", "commit", "-m", "'Bumped version'"])
 
 
